# PicoRun

PicoRun is a small collection of classes used by the default PicoFun 
implementation at run time. These classes don't do a lot, but they help keep 
the cost simple. Spinning the out into this package prevents lots of 
duplication. These functions are baked into a common lambda layer so the 
lambda functions stay small.

For more information about PicoFun, check out the [project on 
GitHub](https://github.com/proactiveops/picofun).
